<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">O prohlížeči</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autoři</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Lehký webový prohlížeč založený na WebKitu</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation>Verze WebKitu: %1</translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Jazyky</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Jazyky v pořadí přednosti:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Posunout &amp;výše</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Posunout &amp;níže</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Odebrat</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Přidat...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation>Blokováno AdBlock pravidlem: %1</translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation>Přidat vlastní pravidlo</translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation>Více informací o psaní pravidel...</translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation>Aktualizovat cizí filtry</translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation>Prohlížet cizí filtry...</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Odstranilt cizí filtry</translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation>Konfigurace AdBlock</translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation>Povolit AdBlock</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akce</translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation>Vlastní pravidla</translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation>Pravidlo</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation>Přidat cizí filtry?</translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation>Přidat tyto AdBlock cizí filtry?
%1</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Přidat záložku</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Napiš jméno pro záložku, a vyber, kam ji uchovat.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titulek</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Přidat složku</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation>Formulář hesel</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Smazat vše</translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation>&lt;b&gt;Chceš uložit toto heslo?&lt;/b&gt;&lt;br&gt;         Pro prohlížení uložených hesel a jejich odstranění otevřete kartu AutoFill v dialogu nastavení.</translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation>Nikdy na této stránce</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation>Nyní ne</translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation>Webová stránka</translation>
    </message>
    <message>
        <source>User Name</source>
        <translation>Uživatelské jméno</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nová složka</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Přidat složku</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Otevřít v novém panelu</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Upravit název</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Upravit adresu</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Chyba při načítání záložek na řádku %1, sloupci %2: %3</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Panel záložek</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Menu záložek</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Nástrojová lista záložek</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importováno %1</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml *.html)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml *.html)</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Chyba při načítání HTML záložek: %1
</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Chyba exportu</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>chyba při ukládání záložek</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Smazat záložku</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Vložit záložku</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">Změna jména</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">Změna adresy</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Změna jména</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Změna adresy</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>XBEL záložky</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>Netscape HTML záložky</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>je vyžadován nástroj htmlToXBel</translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>nástroj htmlToXBel, který je dodáván s Arorou a je nutný k importu HTMl záložek, není nainstalován nebo není dostupný v hledaných cestách.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Načítám záložku</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Chyba při načítání HTML záložek: %1
</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Otevřít v panelech</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Titulek</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Záložky</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Otevřít v &amp;novém panelu</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Přidat záložku...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Přidat složku...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Záložky</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Je otevřeno %1 oken a %2 panelů
Přesto ukončit?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Obnovení selhalo</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Uložená relace nebude obnovena, protože Arora spadla při pokusu o její obnovení.</translation>
    </message>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete">(Revize: %1 %2)</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation>Arora spadla při pokusu o obnovu této relace. Zkusit znovu?</translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Nové okno</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>Otevřít &amp;soubor...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>&amp;Otevřít adresu...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Uložit jako...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importovat záložky...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Exportovat záložky...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Ná&amp;hled tisku...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Tisk...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Soukro&amp;mé prohlížení...</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Zavřít okno</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Úpr&amp;avy</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Zn&amp;ovu</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Vyjmout</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>V&amp;ložit</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Na&amp;jít</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>O &amp;%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Když je zapnuto soukromé prohlížení, některé akce narušující tvoje soukromí budou zakázány:&lt;ul&gt;&lt;li&gt; Stránky nejsou přidávány do historie.&lt;/li&gt;&lt;li&gt; Položky jsou automaticky smazány z okna stahování.&lt;/li&gt;&lt;li&gt; Nové cookies nejsou uloženy, aktuální nebudou přístupné.&lt;/li&gt;&lt;li&gt; Ikony stránek nejsou ukládány, relace taky ne.&lt;/li&gt;&lt;li&gt; Hledání nejsou přidávány do vyjížděcího menu v políčku hledání.&lt;/li&gt;&lt;/ul&gt;Dokud nezavřeš okno, můžeš vždy klikat Zpět a Vpřed pro vrácení na dříve otevřené stránky.</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Find Next</source>
        <translation type="obsolete">Nají&amp;t další</translation>
    </message>
    <message>
        <source>&amp;Find Previous</source>
        <translation type="obsolete">Najít &amp;předchozí</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="obsolete">Před&amp;volby</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Zobrazit</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Z&amp;astavit</translation>
    </message>
    <message>
        <source>Reload Page</source>
        <translation type="obsolete">O&amp;bnovit</translation>
    </message>
    <message>
        <source>&amp;Make Text Bigger</source>
        <translation type="obsolete">Z&amp;většit písmo</translation>
    </message>
    <message>
        <source>&amp;Make Text Normal</source>
        <translation type="obsolete">&amp;Normální velikost písma</translation>
    </message>
    <message>
        <source>&amp;Make Text Smaller</source>
        <translation type="obsolete">Z&amp;menšit písmo</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>&amp;Zdrojový kód stránky</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Historie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vpřed</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Domů</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Obnovit poslední relaci</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>Zál&amp;ožky</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">Spravovat záložky...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Přidat záložku...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Přidat složku...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Hledání na webu</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Zobrazit &amp;monitor sítě</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Povolit Web &amp;Inspector</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">O &amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigace</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Zobrazit stavový řádek</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Skrýt stavový řádek</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Zobrazit panel nástrojů</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Skrýt panel nástrojů</translation>
    </message>
    <message>
        <source>Show Bookmarks bar</source>
        <translation type="obsolete">Zobrazit panel záložek</translation>
    </message>
    <message>
        <source>Hide Bookmarks bar</source>
        <translation type="obsolete">Skrýt panel záložek</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation type="obsolete">Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">O prohlížeči</translation>
    </message>
    <message>
        <source>Version %1&lt;p&gt;This demo demonstrates Qt&apos;s webkit facilities in action, providing an example browser for you to experiment with.&lt;p&gt;&lt;p&gt;QtWebKit is based on the Open Source WebKit Project developed at &lt;a href=&quot;http://webkit.org/&quot;&gt;http://webkit.org/&lt;/a&gt;.</source>
        <translation type="obsolete">Verze %1&lt;p&gt;Tato ukázka předvádí schopnosti WebKitu v Qt v akci, poskytnutím vzorového prohlížeče, abys s ním mohl(a) experimentovat.&lt;p&gt;&lt;p&gt;QtWebKit je založen na open-source projektu WebKit vyvíjeného na &lt;a href=&quot;http://webkit.org/&quot;&gt;http://webkit.org/&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Otevřít webovou stránku</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Webové stránky (*.html *.htm *.svg *.png *.gif *.svgz);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Vytisknout dokument</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Opravdu chceš zapnout soukromé prohlížení?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing in turned on, webpages are not added to the history, items are automatically removed from the Downloads window, new cookies are not stored, current cookies can&apos;t be accessed, site icons wont be stored, session wont be saved,  and searches are not addded to the pop-up menu in the Google search box.  Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Když je zapnuto soukromé prohlížení, stránky nejsou přidávány do historie, soubory jsou automaticky smazány z okna stahování, nové cookies nejsou ukládány, aktuální cookies nejsou přístupné, ikony stránek nejsou ukládány, relace se neukádá a hledání nejsou přidávány do vysouvacího menu v políčku Google hledání. Dokud nezavřeš okno, můžeš vždy klikat Zpět a Vpřed pro vrácení na dříve otevřené stránky.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Opravdu chceš zavřít okno? Je tu otevřeno %1 panelů</translation>
    </message>
    <message>
        <source>Page Source of %1</source>
        <translation type="obsolete">Zdrojový kód stránky %1</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Web Inspector</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Webový inspektor bude fungovat pouze pro stránky načtené po jeho povolení. Chceš znovu načíst všechny stránky?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Zastaví načítání aktuální stránky</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Znovu načte aktuální stránku</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation type="obsolete">Alt+Ctrl+L</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>Smazat &amp;soukromá data</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttonsto return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Když je zapnuto soukromé prohlížení, některé akce narušující tvoje soukromí budou zakázány:&lt;ul&gt;&lt;li&gt; Stránky nejsou přidávány do historie.&lt;/li&gt;&lt;li&gt; Položky jsou automaticky smazány z okna stahování.&lt;/li&gt;&lt;li&gt; Nové cookies nejsou uloženy, aktuální nebudou přístupné.&lt;/li&gt;&lt;li&gt; Ikony stránek nejsou ukládány, relace taky ne.&lt;/li&gt;&lt;li&gt; Hledání nejsou přidávány do vyjížděcího menu v políčku hledání.&lt;/li&gt;&lt;/ul&gt;Dokud nezavřeš okno, můžeš vždy klikat Zpět a Vpřed pro vrácení na dříve otevřené stránky.</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Když je zapnuto soukromé prohlížení, některé akce narušující tvoje soukromí budou zakázány:&lt;ul&gt;&lt;li&gt; Stránky nejsou přidávány do historie.&lt;/li&gt;&lt;li&gt; Položky jsou automaticky smazány z okna stahování.&lt;/li&gt;&lt;li&gt; Nové cookies nejsou uloženy, aktuální nebudou přístupné.&lt;/li&gt;&lt;li&gt; Ikony stránek nejsou ukládány, relace taky ne.&lt;/li&gt;&lt;li&gt; Hledání nejsou přidávány do vyjížděcího menu v políčku hledání.&lt;/li&gt;&lt;/ul&gt;Dokud nezavřeš okno, můžeš vždy klikat Zpět a Vpřed pro vrácení na dříve otevřené stránky.</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Zobrazit panel záložek</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Skrýt panel záložek</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation type="obsolete">Nají&amp;t další</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Najít &amp;předchozí</translation>
    </message>
    <message>
        <source>Prefe&amp;rences</source>
        <translation type="obsolete">Před&amp;volby</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>O&amp;bnovit stránku</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">Z&amp;většit text</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">&amp;Normální velikost textu</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">Z&amp;menšit text</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Nají&amp;t další</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Před&amp;volby...</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Zobrazit menu</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Při&amp;blížit</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>&amp;Normální velikost</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Od&amp;dálit</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Přibližovat pouze &amp;text</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Zobrazit všechny záložky...</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Přepnout jazyk aplikace </translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Kódování textu</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Vybr&amp;at vše</translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Nastavení...</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation>Nastavit vyhledávací enginy...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation>&amp;AdBlock...</translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation>Při zapnutém soukromém prolížení budou některé akce týkající se tvého soukromí zakázány:</translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation>Stránky nejsou přidávány do historie.</translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation>Soubory jsou automaticky smazávány z okna stahování.</translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation>Nové cookies nejsou uloženy, ke stávajícím cookies nemůže být přistupováno.</translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation>Ikony stránek nebudou ukládány.</translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation>Relace nebude uložena.</translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation>Vyhledávání nejsou přidávány do pop-up menu vyhledávacího políčka.</translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation>Síťová cache není ukládána na disk.</translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation>Dokud nezavřeš okno, pořád se můžeš pomocí tlačítek Zpět a Vpřed vrátit na stránky, které jsi otevřel.</translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation>Soukromé prohlížení</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Vyčistit</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Vyčistit soukromá data</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Vyčistit tyto položky:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;Historie prohlížení</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Historie &amp;stahování</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Historie hledání</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>C&amp;ache</source>
        <translation type="obsolete">Vyrovnávací &amp;paměť</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>Ikony stránek</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Vyčistit soukromá data</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>Stránky v &amp;cache</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Načíst</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Načíst vše</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>Přidat %1 do povolených</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Odebar z povolených</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Načíst flash</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Povolené weby</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="obsolete">Stav</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Povoleno</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blokovat</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Povolit pro relaci</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Pravidlo</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Zabezpečené</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Vyprší</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>true</source>
        <translation></translation>
    </message>
    <message>
        <source>false</source>
        <translation></translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Relační cookie</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Smazat &amp;vše</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Přidat &amp;pravidlo</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Výjimky pro cookies</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nová výjimka</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Doména:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blokovat</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Povolit pro relaci</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Výjimky</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Smazat &amp;vše</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Vyčistit</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 položek</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Ico</source>
        <translation></translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Zkusit znovu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Stahování zrušeno: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 z %2 (%3/sek) - %4</translation>
    </message>
    <message>
        <source>Error opening save file: %1</source>
        <translation type="obsolete">Chyba při otevírání souboru pro uložení: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Chyba při ukládání: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Chyba sítě: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">sekund</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minut</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation type="obsolete">- %4 %5 zbývá</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 z %2 (%3/s) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 z %2 - Zastaveno</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">bajtů</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>- %n minuta zbývá</numerusform>
            <numerusform>- %n minuty zbývají</numerusform>
            <numerusform>- %n minut zbývá</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>- %n sekunda zbývá</numerusform>
            <numerusform>- %n sekundy zbývají</numerusform>
            <numerusform>- %n sekund zbývá</numerusform>
        </translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Chyba při otevírání výstupního souboru: %1</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation>Složka pro stahování (%1) nemůže být vytvořena.</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Právě probíhá %1 stahování
Přesto ukončit?</translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>%n minuta zbývá</numerusform>
            <numerusform>%n minuty zbývají</numerusform>
            <numerusform>%n minut zbývá</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>%n sekunda zbývá</numerusform>
            <numerusform>%n sekundy zbývají</numerusform>
            <numerusform>%n sekund zbývá</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bajtů</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>1 Download</source>
        <translation type="obsolete">1 stahování</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <translation type="obsolete">%1 stahování</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n stahování</numerusform>
            <numerusform>%n stahování</numerusform>
            <numerusform>%n stahování</numerusform>
        </translation>
    </message>
    <message>
        <source>GB</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation>Žádná chyba</translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation>Chyba při otevírání %1: Soubor nebo složka neexistuje</translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation>Chyba při čtení %1</translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation>Obsah %1</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Smazat &amp;vše</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Zobrazit všechnu historii</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Vyčistit historii</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Vyčistit historii...</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Chceš smazat historii?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titulek</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Dříve dnes</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="obsolete">%1 položek</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n položka</numerusform>
            <numerusform>%n položky</numerusform>
            <numerusform>%n položek</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation>Vítej v Aroře!</translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation>Hledej!</translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation>Výsledky vyhledávání poskytuje</translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation>O Aroře</translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Default</source>
        <translation type="obsolete">Výchozí</translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Žádné překlady nejsou nainstalovány</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Vyber jazyk</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Arora může používat jiný jazyk, než&lt;br&gt;je výchozí operačního systému.&lt;/p&gt;&lt;p&gt;Prosím vyber, který jazyk má být použit&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation>Žádné překladové soubory nejsou instalovány v %1.</translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Napiš uživatelské jméno a heslo pro &quot;%1&quot; na %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Připojit k proxy &quot;%1&quot; použitím:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - Chyby SSL</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Chyby SSL:&lt;br/&gt;&lt;br/&gt;pro: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Chceš ignorovat tyto chyby?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Certifikáty:&lt;br/&gt;%1&lt;br/&gt;Chceš přijmout všechny tyto certifikáty?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certifactes:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="obsolete">&lt;qt&gt;Certifikáty:&lt;br/&gt;%1&lt;br/&gt;Chceš přijmout všechny tyto certifikáty?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">Chyby SSL:

%1

%2

Chceš ignorovat tyto chyby?</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">Chceš přijmout všechny tyto certifikáty?</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Vydal: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>Neplatný před: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Platný od: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Alternativní jména:</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Název</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Hodnota</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Monitor sítě</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Síťové požadavky</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Hlavičky požadavku</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Hlavičky odpovědi</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Smazat</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Smazat &amp;všechny požadavky</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation></translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 není validní OpenSearch 1.1 popis, nebo už je na seznamu.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Musíš mít alespoň jeden vyhledávací engine.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>Správce OpenSearch</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Obnovit původní</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřit</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Popis:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>Poskytuje kontextové návrhy</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation>Čárkou oddělený seznam klíčkových slov, které mají být vloženy do vyhledávacího políčka následovány vyhledávanými slovy s tímto enginem</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Klíčová slova</translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Chceš přidat následující engine do seznamu tvých vyhledávacích enginů?&lt;br /&gt;&lt;br /&gt;Jméno: %1&lt;br /&gt;Vyhledává na: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Vyžadované přihlášení</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation></translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Nenalezeno</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Přihlášení k proxy</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Připojit k proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Soubor není XBEL verze 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Neznámý titulek</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>Toto není OpeSearch 1.1 soubor.</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Přesměrování: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Metoda</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Adresa</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Odpověď</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Délka</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Typ obsahu</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Info</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation>Vyznačit vše</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Nastavení</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Hlavní</translation>
    </message>
    <message>
        <source>Home:</source>
        <translation type="obsolete">Domov:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Nastav na aktuální stránku</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Odstranit položky historie:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Po jednom dni</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Po jednom týdnu</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Po dvou týdnech</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Po měsíci</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Po roce</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Ručně</translation>
    </message>
    <message>
        <source>Save downloads to:</source>
        <translation type="obsolete">Uložit stahování do:</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Otevřít odkazy z aplikací:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">V panelu v aktuálním okně</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>V novém okně</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Standardní písmo:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Vybrat...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Písmo s pevnou šířkou:</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation type="obsolete">Courier 13</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Upřednostňované jazyky pro prohlížení stránek:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Soukromí</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Obsah webu</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Blokovat vyskakovací okna</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Povolit plug-iny</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Povolit JavaScript</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Přijímat cookies:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Vždy</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Pouze z navštívených stránek</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Výjimky...</translation>
    </message>
    <message>
        <source>Keep until:</source>
        <translation type="obsolete">Uchovat dokud:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Vyprší</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Ukončení aplikace</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Maximálně 90 dní</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies...</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Enable proxy</source>
        <translation type="obsolete">Povolit proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation type="obsolete">Http</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="obsolete">Server:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Rozšířené</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>CSS styl:</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Vždy se ptát na umístění stahování</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Použít toto umístění:</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Při ukončení aplikace</translation>
    </message>
    <message>
        <source>Enable Images</source>
        <translation type="obsolete">Povolit obrázky</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Panely</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Přepínat na okna nebo panely, když jsou vytvořeny</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">Vyžadovat potvrzení při zavírání více panelů</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Po spuštění:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Zobrazit moji domovskou stránku</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Zobrazit prázdnou stránku</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Obnovit okna a panely z poslední relace</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Domovská stránka:</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Používat ClickToFlash na flash pluginech</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Zobrazit obrázky</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Ponechat cookies dokud:</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Filtrovat sledovací cookies</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Vyžadovat potvzrení při zavírání více panelů nebo oken</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Ukončit aplikaci, když je zavřen poslední panel</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Otevírání odkazů</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Odkazy, které chtějí otevřít v novém okně:</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>V novém panelu aktuálního okna, který bude označen</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>V novém panelu aktuálního okna</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>V aktuálním panelu</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Použít proxy server</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>HTTP (zabezpečené)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>HTTP (průhledné)</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Jméno hostitele:</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Povolit síťovou cache</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Maximální velikost:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation></translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Zobrazit pouze jedno zavírací tlačítko místo jednoho pro každý panel</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation>Použít výchozí vyhledávácí engine jako nouzový, když URL zadaná uživatelem je neplatná</translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation>Vybrat složku...</translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation>Relace session končí:</translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation>Když ukončím aplikaci</translation>
    </message>
    <message>
        <source>1 day</source>
        <translation>1 den</translation>
    </message>
    <message>
        <source>2 days</source>
        <translation>2 dny</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dny</translation>
    </message>
    <message>
        <source>7 days</source>
        <translation>7 dní</translation>
    </message>
    <message>
        <source>30 days</source>
        <translation>30 dní</translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation>Automaticky doplňovat webové formuláře:</translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation>Uživatelská jména a hesla</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Upravit...</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Prohlížet...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>Vyžadován restart aplikace</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>Byla změněna nastavení síťové cache. Aby se změny projevily, prohlížeč musí být restartován.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation>Vybrat složku</translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation>Vybrat CSS soubor</translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Načítám...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Úpr&amp;avy</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Na&amp;jít</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Zobrazit</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">Za&amp;lamovat řádky</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Zdrojový kód stránky</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Zdrojový kód stránky %1</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">&amp;Nový panel</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Duplikovat panel</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavřít panel</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Zavřít o&amp;statní panely</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Obnovit panel</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Obnovit všechny panely</translation>
    </message>
    <message>
        <source>Show Tab Bar</source>
        <translation>Zobrazit lištu panelů</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Skrýt lištu panelů</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Nový panel</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavřít panel</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Zobrazit další panel</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Uložené panely</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Načítám...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Načítám %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Načítání dokončeno</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Nepovedlo se načíst</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Zobrazit předchozí panel</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Posledně zavřené panely</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Přidat všechny panely do záložek</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation type="obsolete">(Bez titulku)</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Opravdu chceš zavřít tuto stránku?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Stránka byla tebou měněna a když ji zavřeš, změny budou ztraceny.
Opravdu chceš zavřít tuto stránku?
</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Suggestions</source>
        <translation>Návrhy</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>Přidat &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="obsolete">Nastavit vyhledávací enginy...</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Žádná nedávná hledání</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Nedávná hledání</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Vyčistit nedávná hledání</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Chyba při načítání stránky: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Při připojování k: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.trolltech.com instead of &lt;b&gt;www&lt;/b&gt;.trolltech.com.</source>
        <translation type="obsolete">Zkontroluj adresu na chyby jako &lt;b&gt;ww&lt;/b&gt;.trolltech.com místo &lt;b&gt;www&lt;/b&gt;.trolltech.com.</translation>
    </message>
    <message>
        <source>If the address is correct, try to check the network connection.</source>
        <translation type="obsolete">Pokud je adresa správná, zkontroluj síťové připojení.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Pokud je tvůj počítač nebo tvá síť chráněna firewallem nebo proxy, ujisti se, že je prohlížeči povolen přístup k síti.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Zkontroluj adresu na chyby jako &lt;b&gt;ww&lt;/b&gt;.arora-browser.org namísto &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Pokud je adresa správná, zkontroluj síťové připojení.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>Znovuposílám POST požadavek</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Pro zobrazení stránky musí být požadavek spolu se všemi daty poslán znovu, což může způsobit neočekáváné chování stránky, například ta samá akce může být vykonána znovu. Přesto pokračovat?</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation type="obsolete">Otevřít v novém panelu</translation>
    </message>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>&amp;Otevřít v novém okně</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Otevřít v &amp;novém panelu</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Uložit o&amp;dkaz</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Vytvořit záložku pro tento odkaz</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Kopírovat adresu odkazu</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Otevřít obrázek v novém okně</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Otevřít obrázek v novém panelu</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Uložit obrázek</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Kopírovat o&amp;brázek</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Kopírovat adresu ob&amp;rázku</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Hledat pomocí...</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Načítám...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Přidat do políčka vyhledávání</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Metoda není podporována</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>Metoda %1 není podporována.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Vyhledávací engine</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Vyber požadovaný vyhledávací engine</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Název enginu</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Napiš jméno pro engine</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation>Blokovat obrázek</translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Neexistuje</translation>
    </message>
</context>
</TS>
